@@ -4,17 +4,14 @@ from AsyncParse.exceptions import BadStatusException
 
 import aiohttp
 import asyncio 
-import time
 import functools
-import logging
 
 
 class Fetch():
     
-    def __init__(self, reqs_per_sec, data, show_results=True):
+    def __init__(self, reqs_per_sec, data):
         self._semaphore = asyncio.Semaphore(reqs_per_sec)
         self.data = data # define data to later use it with parser func
-        self.show_results = show_results
         
 
     async def _http_request(self, url: str, method: str) -> aiohttp.ClientResponse.text:
@@ -24,13 +21,13 @@ class Fetch():
                 url=url
             )
             self._request_count += 1
-            logging.debug(f"Sending {method} request #{self._request_count} to endpoint {url}")
+            print(f"Sending {method} request #{self._request_count} to endpoint {url}")
             # Rate limiting allow other func to run
             await asyncio.sleep(1)
             if response.ok:
                 return await response.text()
             else:
-                logging.debug("Raised Error: BadStatusException")
+                print("Raised Error: BadStatusException")
                 raise BadStatusException(f'Bad Status: Recieved {response.status}')
     
 
@@ -69,6 +66,5 @@ class Fetch():
                             parse_func(resp)
                         )
 
-
     def __call__(self, urls: list, method: str, parse_func: Callable) -> List[str]:
-        asyncio.run(self._master_req(urls, method, parse_func))
+        asyncio.run(self._master_req(urls, method, parse_func))
\ No newline at end of file
